Page Menu
Home
FreeBSD
Search
Configure Global Search
Log In
Files
F103012452
D47674.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Flag For Later
Award Token
Size
26 KB
Referenced Files
None
Subscribers
None
D47674.diff
View Options
diff --git a/sys/amd64/acpica/acpi_machdep.c b/sys/amd64/acpica/acpi_machdep.c
--- a/sys/amd64/acpica/acpi_machdep.c
+++ b/sys/amd64/acpica/acpi_machdep.c
@@ -267,7 +267,7 @@
{
nexus_init_resources();
- bus_generic_probe(dev);
+ bus_identify_children(dev);
if (BUS_ADD_CHILD(dev, 10, "acpi", 0) == NULL)
panic("failed to add acpi0 device");
diff --git a/sys/arm/arm/gic_acpi.c b/sys/arm/arm/gic_acpi.c
--- a/sys/arm/arm/gic_acpi.c
+++ b/sys/arm/arm/gic_acpi.c
@@ -242,7 +242,7 @@
/* If we have children probe and attach them */
if (arm_gic_add_children(dev)) {
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/arm/arm/gic_fdt.c b/sys/arm/arm/gic_fdt.c
--- a/sys/arm/arm/gic_fdt.c
+++ b/sys/arm/arm/gic_fdt.c
@@ -185,7 +185,7 @@
/* If we have children probe and attach them */
if (arm_gic_add_children(dev)) {
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/arm/arm/nexus.c b/sys/arm/arm/nexus.c
--- a/sys/arm/arm/nexus.c
+++ b/sys/arm/arm/nexus.c
@@ -184,7 +184,7 @@
/*
* Next, deal with the children we know about already.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/arm/broadcom/bcm2835/bcm2835_sdhci.c b/sys/arm/broadcom/bcm2835/bcm2835_sdhci.c
--- a/sys/arm/broadcom/bcm2835/bcm2835_sdhci.c
+++ b/sys/arm/broadcom/bcm2835/bcm2835_sdhci.c
@@ -353,7 +353,7 @@
sc->sc_sdhci_buffer_phys = rman_get_start(sc->sc_mem_res) +
SDHCI_BUFFER;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
sdhci_start_slot(&sc->sc_slot);
diff --git a/sys/arm/broadcom/bcm2835/bcm2835_sdhost.c b/sys/arm/broadcom/bcm2835/bcm2835_sdhost.c
--- a/sys/arm/broadcom/bcm2835/bcm2835_sdhost.c
+++ b/sys/arm/broadcom/bcm2835/bcm2835_sdhost.c
@@ -472,7 +472,7 @@
sdhci_init_slot(dev, &sc->sc_slot, 0);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
sdhci_start_slot(&sc->sc_slot);
diff --git a/sys/arm/nvidia/tegra_sdhci.c b/sys/arm/nvidia/tegra_sdhci.c
--- a/sys/arm/nvidia/tegra_sdhci.c
+++ b/sys/arm/nvidia/tegra_sdhci.c
@@ -386,7 +386,7 @@
sc->gpio = sdhci_fdt_gpio_setup(sc->dev, &sc->slot);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
sdhci_start_slot(&sc->slot);
diff --git a/sys/arm/ti/am335x/am335x_ehrpwm.c b/sys/arm/ti/am335x/am335x_ehrpwm.c
--- a/sys/arm/ti/am335x/am335x_ehrpwm.c
+++ b/sys/arm/ti/am335x/am335x_ehrpwm.c
@@ -517,7 +517,7 @@
// This driver can still do things even without the bus child.
}
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
fail:
PWM_LOCK_DESTROY(sc);
diff --git a/sys/arm/ti/am335x/am335x_pwmss.c b/sys/arm/ti/am335x/am335x_pwmss.c
--- a/sys/arm/ti/am335x/am335x_pwmss.c
+++ b/sys/arm/ti/am335x/am335x_pwmss.c
@@ -150,7 +150,7 @@
/*
* Allow devices to identify.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* Now walk the OFW tree and attach top-level devices.
diff --git a/sys/arm/ti/cpsw/if_cpsw.c b/sys/arm/ti/cpsw/if_cpsw.c
--- a/sys/arm/ti/cpsw/if_cpsw.c
+++ b/sys/arm/ti/cpsw/if_cpsw.c
@@ -911,7 +911,7 @@
return (ENXIO);
}
}
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/arm/ti/ti_omap4_cm.c b/sys/arm/ti/ti_omap4_cm.c
--- a/sys/arm/ti/ti_omap4_cm.c
+++ b/sys/arm/ti/ti_omap4_cm.c
@@ -107,7 +107,7 @@
return (ENXIO);
}
- bus_generic_probe(sc->dev);
+ bus_identify_children(sc->dev);
for (child = OF_child(node); child > 0; child = OF_peer(child)) {
cdev = simplebus_add_device(dev, child, 0, NULL, -1, NULL);
diff --git a/sys/arm/ti/ti_prcm.c b/sys/arm/ti/ti_prcm.c
--- a/sys/arm/ti/ti_prcm.c
+++ b/sys/arm/ti/ti_prcm.c
@@ -188,7 +188,7 @@
#endif
}
- bus_generic_probe(sc->dev);
+ bus_identify_children(sc->dev);
for (child = OF_child(node); child != 0; child = OF_peer(child)) {
simplebus_add_device(dev, child, 0, NULL, -1, NULL);
}
diff --git a/sys/arm/ti/ti_scm_syscon.c b/sys/arm/ti/ti_scm_syscon.c
--- a/sys/arm/ti/ti_scm_syscon.c
+++ b/sys/arm/ti/ti_scm_syscon.c
@@ -185,7 +185,7 @@
simplebus_init(sc->dev, node);
- bus_generic_probe(sc->dev);
+ bus_identify_children(sc->dev);
for (child = OF_child(node); child != 0; child = OF_peer(child)) {
simplebus_add_device(sc->dev, child, 0, NULL, -1, NULL);
}
diff --git a/sys/arm/ti/ti_sdhci.c b/sys/arm/ti/ti_sdhci.c
--- a/sys/arm/ti/ti_sdhci.c
+++ b/sys/arm/ti/ti_sdhci.c
@@ -687,7 +687,7 @@
if (OF_hasprop(node, "non-removable"))
sc->force_card_present = true;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
sdhci_start_slot(&sc->slot);
diff --git a/sys/arm/ti/usb/omap_host.c b/sys/arm/ti/usb/omap_host.c
--- a/sys/arm/ti/usb/omap_host.c
+++ b/sys/arm/ti/usb/omap_host.c
@@ -413,7 +413,7 @@
/*
* Allow devices to identify.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* Now walk the OFW tree and attach top-level devices.
diff --git a/sys/arm64/arm64/nexus.c b/sys/arm64/arm64/nexus.c
--- a/sys/arm64/arm64/nexus.c
+++ b/sys/arm64/arm64/nexus.c
@@ -177,7 +177,7 @@
if (rman_init(&irq_rman) || rman_manage_region(&irq_rman, 0, ~0))
panic("nexus_attach irq_rman");
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/arm64/rockchip/rk_pinctrl.c b/sys/arm64/rockchip/rk_pinctrl.c
--- a/sys/arm64/rockchip/rk_pinctrl.c
+++ b/sys/arm64/rockchip/rk_pinctrl.c
@@ -1511,7 +1511,7 @@
simplebus_init(dev, node);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/* Attach child devices */
for (node = OF_child(node), gpio_unit = 0; node > 0;
diff --git a/sys/contrib/vchiq/interface/vchiq_arm/vchiq_kmod.c b/sys/contrib/vchiq/interface/vchiq_arm/vchiq_kmod.c
--- a/sys/contrib/vchiq/interface/vchiq_arm/vchiq_kmod.c
+++ b/sys/contrib/vchiq/interface/vchiq_arm/vchiq_kmod.c
@@ -192,7 +192,7 @@
vchiq_init();
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/dev/acpi_support/acpi_wmi.c b/sys/dev/acpi_support/acpi_wmi.c
--- a/sys/dev/acpi_support/acpi_wmi.c
+++ b/sys/dev/acpi_support/acpi_wmi.c
@@ -296,7 +296,7 @@
}
if (ret == 0) {
- bus_generic_probe(dev);
+ bus_identify_children(dev);
ret = bus_generic_attach(dev);
}
diff --git a/sys/dev/acpica/acpi.c b/sys/dev/acpica/acpi.c
--- a/sys/dev/acpica/acpi.c
+++ b/sys/dev/acpica/acpi.c
@@ -2284,7 +2284,7 @@
/* Create any static children by calling device identify methods. */
ACPI_DEBUG_PRINT((ACPI_DB_OBJECTS, "device identify routines\n"));
- bus_generic_probe(bus);
+ bus_identify_children(bus);
/* Probe/attach all children, created statically and from the namespace. */
ACPI_DEBUG_PRINT((ACPI_DB_OBJECTS, "acpi bus_generic_attach\n"));
diff --git a/sys/dev/acpica/acpi_container.c b/sys/dev/acpica/acpi_container.c
--- a/sys/dev/acpica/acpi_container.c
+++ b/sys/dev/acpica/acpi_container.c
@@ -103,7 +103,7 @@
acpi_syscont_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/dev/acpica/acpi_cpu.c b/sys/dev/acpica/acpi_cpu.c
--- a/sys/dev/acpica/acpi_cpu.c
+++ b/sys/dev/acpica/acpi_cpu.c
@@ -467,7 +467,7 @@
bus_topo_lock();
CPU_FOREACH(i) {
if ((sc = cpu_softc[i]) != NULL)
- bus_generic_probe(sc->cpu_dev);
+ bus_identify_children(sc->cpu_dev);
}
CPU_FOREACH(i) {
if ((sc = cpu_softc[i]) != NULL) {
diff --git a/sys/dev/acpica/acpi_pcib_acpi.c b/sys/dev/acpica/acpi_pcib_acpi.c
--- a/sys/dev/acpica/acpi_pcib_acpi.c
+++ b/sys/dev/acpica/acpi_pcib_acpi.c
@@ -528,7 +528,7 @@
/* Don't fail to attach if the domain can't be queried or set. */
error = 0;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
if (device_add_child(dev, "pci", -1) == NULL) {
bus_dma_tag_destroy(sc->ap_dma_tag);
sc->ap_dma_tag = NULL;
diff --git a/sys/dev/atkbdc/atkbdc_isa.c b/sys/dev/atkbdc/atkbdc_isa.c
--- a/sys/dev/atkbdc/atkbdc_isa.c
+++ b/sys/dev/atkbdc/atkbdc_isa.c
@@ -238,7 +238,7 @@
}
*(atkbdc_softc_t **)device_get_softc(dev) = sc;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return 0;
diff --git a/sys/dev/cxgbe/t4_main.c b/sys/dev/cxgbe/t4_main.c
--- a/sys/dev/cxgbe/t4_main.c
+++ b/sys/dev/cxgbe/t4_main.c
@@ -1624,11 +1624,7 @@
goto done;
}
- rc = bus_generic_probe(dev);
- if (rc != 0) {
- device_printf(dev, "failed to probe child drivers: %d\n", rc);
- goto done;
- }
+ bus_identify_children(dev);
/*
* Ensure thread-safe mailbox access (in debug builds).
diff --git a/sys/dev/dpaa2/dpaa2_mc.c b/sys/dev/dpaa2/dpaa2_mc.c
--- a/sys/dev/dpaa2/dpaa2_mc.c
+++ b/sys/dev/dpaa2/dpaa2_mc.c
@@ -268,7 +268,7 @@
dpaa2_mc_detach(dev);
return (ENXIO);
}
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/dev/dpaa2/dpaa2_mc_fdt.c b/sys/dev/dpaa2/dpaa2_mc_fdt.c
--- a/sys/dev/dpaa2/dpaa2_mc_fdt.c
+++ b/sys/dev/dpaa2/dpaa2_mc_fdt.c
@@ -253,11 +253,12 @@
sc->acpi_based = false;
sc->ofw_node = ofw_bus_get_node(dev);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
+
/*
* Attach the children represented in the device tree.
*/
diff --git a/sys/dev/dpaa2/memac_mdio_acpi.c b/sys/dev/dpaa2/memac_mdio_acpi.c
--- a/sys/dev/dpaa2/memac_mdio_acpi.c
+++ b/sys/dev/dpaa2/memac_mdio_acpi.c
@@ -262,7 +262,7 @@
ACPI_SCAN_CHILDREN(device_get_parent(dev), dev, 1,
memac_mdio_acpi_probe_child, &ctx);
if (ctx.countok > 0) {
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
}
diff --git a/sys/dev/dpaa2/memac_mdio_fdt.c b/sys/dev/dpaa2/memac_mdio_fdt.c
--- a/sys/dev/dpaa2/memac_mdio_fdt.c
+++ b/sys/dev/dpaa2/memac_mdio_fdt.c
@@ -238,7 +238,7 @@
return (error);
/* Attach the *phy* children represented in the device tree. */
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
node = ofw_bus_get_node(dev);
simplebus_init(dev, node);
diff --git a/sys/dev/etherswitch/ar40xx/ar40xx_main.c b/sys/dev/etherswitch/ar40xx/ar40xx_main.c
--- a/sys/dev/etherswitch/ar40xx/ar40xx_main.c
+++ b/sys/dev/etherswitch/ar40xx/ar40xx_main.c
@@ -482,7 +482,7 @@
/* Attach PHYs */
ret = ar40xx_attach_phys(sc);
- ret = bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
ret = bus_generic_attach(dev);
diff --git a/sys/dev/etherswitch/arswitch/arswitch.c b/sys/dev/etherswitch/arswitch/arswitch.c
--- a/sys/dev/etherswitch/arswitch/arswitch.c
+++ b/sys/dev/etherswitch/arswitch/arswitch.c
@@ -649,7 +649,7 @@
return (err);
}
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
if (err != 0) {
diff --git a/sys/dev/etherswitch/e6000sw/e6000sw.c b/sys/dev/etherswitch/e6000sw/e6000sw.c
--- a/sys/dev/etherswitch/e6000sw/e6000sw.c
+++ b/sys/dev/etherswitch/e6000sw/e6000sw.c
@@ -642,7 +642,7 @@
device_printf(dev, "switch is ready.\n");
E6000SW_UNLOCK(sc);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
taskqueue_enqueue_timeout(sc->sc_tq, &sc->sc_tt, hz);
diff --git a/sys/dev/etherswitch/e6000sw/e6060sw.c b/sys/dev/etherswitch/e6000sw/e6060sw.c
--- a/sys/dev/etherswitch/e6000sw/e6060sw.c
+++ b/sys/dev/etherswitch/e6000sw/e6060sw.c
@@ -306,7 +306,7 @@
if (err != 0)
return (err);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
if (err != 0)
diff --git a/sys/dev/etherswitch/felix/felix.c b/sys/dev/etherswitch/felix/felix.c
--- a/sys/dev/etherswitch/felix/felix.c
+++ b/sys/dev/etherswitch/felix/felix.c
@@ -463,7 +463,7 @@
FELIX_UNLOCK(sc);
/* Allow etherswitch to attach as our child. */
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/dev/etherswitch/infineon/adm6996fc.c b/sys/dev/etherswitch/infineon/adm6996fc.c
--- a/sys/dev/etherswitch/infineon/adm6996fc.c
+++ b/sys/dev/etherswitch/infineon/adm6996fc.c
@@ -258,7 +258,7 @@
if (err != 0)
goto failed;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
if (err != 0)
diff --git a/sys/dev/etherswitch/ip17x/ip17x.c b/sys/dev/etherswitch/ip17x/ip17x.c
--- a/sys/dev/etherswitch/ip17x/ip17x.c
+++ b/sys/dev/etherswitch/ip17x/ip17x.c
@@ -257,7 +257,7 @@
*/
sc->hal.ip17x_set_vlan_mode(sc, ETHERSWITCH_VLAN_PORT);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
if (err != 0)
diff --git a/sys/dev/etherswitch/micrel/ksz8995ma.c b/sys/dev/etherswitch/micrel/ksz8995ma.c
--- a/sys/dev/etherswitch/micrel/ksz8995ma.c
+++ b/sys/dev/etherswitch/micrel/ksz8995ma.c
@@ -308,7 +308,7 @@
if (err != 0)
goto failed;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
if (err != 0)
diff --git a/sys/dev/etherswitch/mtkswitch/mtkswitch.c b/sys/dev/etherswitch/mtkswitch/mtkswitch.c
--- a/sys/dev/etherswitch/mtkswitch/mtkswitch.c
+++ b/sys/dev/etherswitch/mtkswitch/mtkswitch.c
@@ -231,7 +231,7 @@
if (err != 0)
return (err);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
DPRINTF(dev, "%s: bus_generic_attach: err=%d\n", __func__, err);
diff --git a/sys/dev/etherswitch/rtl8366/rtl8366rb.c b/sys/dev/etherswitch/rtl8366/rtl8366rb.c
--- a/sys/dev/etherswitch/rtl8366/rtl8366rb.c
+++ b/sys/dev/etherswitch/rtl8366/rtl8366rb.c
@@ -254,7 +254,7 @@
}
}
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
if (err != 0)
diff --git a/sys/dev/etherswitch/ukswitch/ukswitch.c b/sys/dev/etherswitch/ukswitch/ukswitch.c
--- a/sys/dev/etherswitch/ukswitch/ukswitch.c
+++ b/sys/dev/etherswitch/ukswitch/ukswitch.c
@@ -209,7 +209,7 @@
if (err != 0)
return (err);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
err = bus_generic_attach(dev);
if (err != 0)
diff --git a/sys/dev/firewire/firewire.c b/sys/dev/firewire/firewire.c
--- a/sys/dev/firewire/firewire.c
+++ b/sys/dev/firewire/firewire.c
@@ -452,7 +452,7 @@
0, 0, "fw%d_probe", unit);
/* Locate our children */
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/* launch attachement of the added children */
bus_generic_attach(dev);
diff --git a/sys/dev/firewire/fwohci_pci.c b/sys/dev/firewire/fwohci_pci.c
--- a/sys/dev/firewire/fwohci_pci.c
+++ b/sys/dev/firewire/fwohci_pci.c
@@ -314,7 +314,7 @@
}
/* probe and attach a child device(firewire) */
- bus_generic_probe(self);
+ bus_identify_children(self);
bus_generic_attach(self);
return 0;
diff --git a/sys/dev/firmware/arm/scmi.c b/sys/dev/firmware/arm/scmi.c
--- a/sys/dev/firmware/arm/scmi.c
+++ b/sys/dev/firmware/arm/scmi.c
@@ -174,7 +174,7 @@
/*
* Allow devices to identify.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* Now walk the OFW tree and attach top-level devices.
diff --git a/sys/dev/gpio/dwgpio/dwgpio_bus.c b/sys/dev/gpio/dwgpio/dwgpio_bus.c
--- a/sys/dev/gpio/dwgpio/dwgpio_bus.c
+++ b/sys/dev/gpio/dwgpio/dwgpio_bus.c
@@ -94,7 +94,7 @@
/*
* Allow devices to identify.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* Now walk the OFW tree and attach top-level devices.
diff --git a/sys/dev/gpio/gpiobus.c b/sys/dev/gpio/gpiobus.c
--- a/sys/dev/gpio/gpiobus.c
+++ b/sys/dev/gpio/gpiobus.c
@@ -560,7 +560,7 @@
/*
* Get parent's pins and mark them as unmapped
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
return (bus_generic_attach(dev));
diff --git a/sys/dev/gpio/ofw_gpiobus.c b/sys/dev/gpio/ofw_gpiobus.c
--- a/sys/dev/gpio/ofw_gpiobus.c
+++ b/sys/dev/gpio/ofw_gpiobus.c
@@ -425,7 +425,7 @@
err = gpiobus_init_softc(dev);
if (err != 0)
return (err);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
/*
* Attach the children represented in the device tree.
diff --git a/sys/dev/hid/hidbus.c b/sys/dev/hid/hidbus.c
--- a/sys/dev/hid/hidbus.c
+++ b/sys/dev/hid/hidbus.c
@@ -267,7 +267,7 @@
* attach twice in that case.
*/
sc->nest++;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
sc->nest--;
if (sc->nest != 0)
return (0);
diff --git a/sys/dev/hyperv/vmbus/vmbus.c b/sys/dev/hyperv/vmbus/vmbus.c
--- a/sys/dev/hyperv/vmbus/vmbus.c
+++ b/sys/dev/hyperv/vmbus/vmbus.c
@@ -559,7 +559,7 @@
/*
* Identify, probe and attach for non-channel devices.
*/
- bus_generic_probe(sc->vmbus_dev);
+ bus_identify_children(sc->vmbus_dev);
bus_generic_attach(sc->vmbus_dev);
/*
diff --git a/sys/dev/iicbus/iicbus.c b/sys/dev/iicbus/iicbus.c
--- a/sys/dev/iicbus/iicbus.c
+++ b/sys/dev/iicbus/iicbus.c
@@ -125,7 +125,7 @@
}
printf("\n");
#endif
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/dev/iicbus/ofw_iicbus.c b/sys/dev/iicbus/ofw_iicbus.c
--- a/sys/dev/iicbus/ofw_iicbus.c
+++ b/sys/dev/iicbus/ofw_iicbus.c
@@ -127,7 +127,7 @@
iicbus_reset(dev, IIC_FASTEST, 0, NULL);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
/*
diff --git a/sys/dev/mdio/mdio.c b/sys/dev/mdio/mdio.c
--- a/sys/dev/mdio/mdio.c
+++ b/sys/dev/mdio/mdio.c
@@ -54,7 +54,7 @@
mdio_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/dev/ofw/ofw_cpu.c b/sys/dev/ofw/ofw_cpu.c
--- a/sys/dev/ofw/ofw_cpu.c
+++ b/sys/dev/ofw/ofw_cpu.c
@@ -297,7 +297,7 @@
if (sc->sc_nominal_mhz != 0 && bootverbose)
device_printf(dev, "Nominal frequency %dMhz\n",
sc->sc_nominal_mhz);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/dev/ofw/ofwbus.c b/sys/dev/ofw/ofwbus.c
--- a/sys/dev/ofw/ofwbus.c
+++ b/sys/dev/ofw/ofwbus.c
@@ -117,7 +117,7 @@
/*
* Allow devices to identify.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* Now walk the OFW tree and attach top-level devices.
diff --git a/sys/dev/pci/hostb_pci.c b/sys/dev/pci/hostb_pci.c
--- a/sys/dev/pci/hostb_pci.c
+++ b/sys/dev/pci/hostb_pci.c
@@ -69,7 +69,7 @@
pci_hostb_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* If AGP capabilities are present on this device, then create
diff --git a/sys/dev/pci/isa_pci.c b/sys/dev/pci/isa_pci.c
--- a/sys/dev/pci/isa_pci.c
+++ b/sys/dev/pci/isa_pci.c
@@ -160,7 +160,7 @@
isab_pci_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (isab_attach(dev));
}
diff --git a/sys/dev/pci/vga_pci.c b/sys/dev/pci/vga_pci.c
--- a/sys/dev/pci/vga_pci.c
+++ b/sys/dev/pci/vga_pci.c
@@ -366,7 +366,7 @@
vga_pci_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/* Always create a drmn child for now to make it easier on drm. */
device_add_child(dev, "drmn", DEVICE_UNIT_ANY);
diff --git a/sys/dev/ppbus/ppbconf.c b/sys/dev/ppbus/ppbconf.c
--- a/sys/dev/ppbus/ppbconf.c
+++ b/sys/dev/ppbus/ppbconf.c
@@ -404,7 +404,7 @@
}
/* Locate our children */
- bus_generic_probe(dev);
+ bus_identify_children(dev);
#ifndef DONTPROBE_1284
/* detect IEEE1284 compliant devices */
diff --git a/sys/dev/pwm/ofw_pwmbus.c b/sys/dev/pwm/ofw_pwmbus.c
--- a/sys/dev/pwm/ofw_pwmbus.c
+++ b/sys/dev/pwm/ofw_pwmbus.c
@@ -184,7 +184,7 @@
}
}
bus_enumerate_hinted_children(dev);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/dev/pwm/pwmbus.c b/sys/dev/pwm/pwmbus.c
--- a/sys/dev/pwm/pwmbus.c
+++ b/sys/dev/pwm/pwmbus.c
@@ -182,7 +182,7 @@
}
bus_enumerate_hinted_children(dev);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/dev/sdhci/fsl_sdhci.c b/sys/dev/sdhci/fsl_sdhci.c
--- a/sys/dev/sdhci/fsl_sdhci.c
+++ b/sys/dev/sdhci/fsl_sdhci.c
@@ -925,7 +925,7 @@
sdhci_init_slot(dev, &sc->slot, 0);
sc->slot_init_done = true;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
sdhci_start_slot(&sc->slot);
diff --git a/sys/dev/smbus/smbus.c b/sys/dev/smbus/smbus.c
--- a/sys/dev/smbus/smbus.c
+++ b/sys/dev/smbus/smbus.c
@@ -67,7 +67,7 @@
struct smbus_softc *sc = device_get_softc(dev);
mtx_init(&sc->lock, device_get_nameunit(dev), "smbus", MTX_DEF);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
bus_generic_attach(dev);
diff --git a/sys/dev/spibus/ofw_spibus.c b/sys/dev/spibus/ofw_spibus.c
--- a/sys/dev/spibus/ofw_spibus.c
+++ b/sys/dev/spibus/ofw_spibus.c
@@ -83,7 +83,7 @@
sc->dev = dev;
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_enumerate_hinted_children(dev);
/*
diff --git a/sys/dev/sram/mmio_sram.c b/sys/dev/sram/mmio_sram.c
--- a/sys/dev/sram/mmio_sram.c
+++ b/sys/dev/sram/mmio_sram.c
@@ -94,7 +94,7 @@
/*
* Allow devices to identify.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* Now walk the OFW tree and attach top-level devices.
diff --git a/sys/dev/superio/superio.c b/sys/dev/superio/superio.c
--- a/sys/dev/superio/superio.c
+++ b/sys/dev/superio/superio.c
@@ -717,7 +717,7 @@
sc->known_devices[i].ldn);
}
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
sc->chardev = make_dev(&superio_cdevsw, device_get_unit(dev),
diff --git a/sys/dev/xen/bus/xenpv.c b/sys/dev/xen/bus/xenpv.c
--- a/sys/dev/xen/bus/xenpv.c
+++ b/sys/dev/xen/bus/xenpv.c
@@ -126,9 +126,7 @@
* can find. Once that is done attach any devices that we
* found.
*/
- error = bus_generic_probe(dev);
- if (error)
- return (error);
+ bus_identify_children(dev);
error = bus_generic_attach(dev);
diff --git a/sys/dev/xen/xenstore/xenstore.c b/sys/dev/xen/xenstore/xenstore.c
--- a/sys/dev/xen/xenstore/xenstore.c
+++ b/sys/dev/xen/xenstore/xenstore.c
@@ -1068,7 +1068,7 @@
xs_attach_deferred(void *arg)
{
- bus_generic_probe(xs.xs_dev);
+ bus_identify_children(xs.xs_dev);
bus_generic_attach(xs.xs_dev);
config_intrhook_disestablish(&xs.xs_attachcb);
@@ -1079,7 +1079,7 @@
{
KASSERT((pending == 1), ("xs late attach queued several times"));
- bus_generic_probe(xs.xs_dev);
+ bus_identify_children(xs.xs_dev);
bus_generic_attach(xs.xs_dev);
}
diff --git a/sys/i386/acpica/acpi_machdep.c b/sys/i386/acpica/acpi_machdep.c
--- a/sys/i386/acpica/acpi_machdep.c
+++ b/sys/i386/acpica/acpi_machdep.c
@@ -286,7 +286,7 @@
{
nexus_init_resources();
- bus_generic_probe(dev);
+ bus_identify_children(dev);
if (BUS_ADD_CHILD(dev, 10, "acpi", 0) == NULL)
panic("failed to add acpi0 device");
diff --git a/sys/isa/isa_common.c b/sys/isa/isa_common.c
--- a/sys/isa/isa_common.c
+++ b/sys/isa/isa_common.c
@@ -501,7 +501,7 @@
* Create all the non-hinted children by calling drivers'
* identify methods.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
if (device_get_children(dev, &children, &nchildren))
return;
diff --git a/sys/isa/vga_isa.c b/sys/isa/vga_isa.c
--- a/sys/isa/vga_isa.c
+++ b/sys/isa/vga_isa.c
@@ -259,7 +259,7 @@
vgapm_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/powerpc/mambo/mambo.c b/sys/powerpc/mambo/mambo.c
--- a/sys/powerpc/mambo/mambo.c
+++ b/sys/powerpc/mambo/mambo.c
@@ -90,6 +90,6 @@
static int
mambobus_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
return (bus_generic_attach(dev));
}
diff --git a/sys/powerpc/powerpc/nexus.c b/sys/powerpc/powerpc/nexus.c
--- a/sys/powerpc/powerpc/nexus.c
+++ b/sys/powerpc/powerpc/nexus.c
@@ -141,7 +141,7 @@
device_add_child(dev, "ofwbus", 0);
/* Now, probe children. */
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/riscv/riscv/nexus.c b/sys/riscv/riscv/nexus.c
--- a/sys/riscv/riscv/nexus.c
+++ b/sys/riscv/riscv/nexus.c
@@ -171,7 +171,7 @@
nexus_add_child(dev, 1, "rcons", 0);
nexus_add_child(dev, 2, "ofwbus", 0);
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
diff --git a/sys/x86/x86/legacy.c b/sys/x86/x86/legacy.c
--- a/sys/x86/x86/legacy.c
+++ b/sys/x86/x86/legacy.c
@@ -161,7 +161,7 @@
* can find. Once that is done attach any devices that we
* found.
*/
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
/*
@@ -342,7 +342,7 @@
static int
cpu_attach(device_t dev)
{
- bus_generic_probe(dev);
+ bus_identify_children(dev);
bus_generic_attach(dev);
return (0);
}
diff --git a/sys/x86/x86/nexus.c b/sys/x86/x86/nexus.c
--- a/sys/x86/x86/nexus.c
+++ b/sys/x86/x86/nexus.c
@@ -262,7 +262,7 @@
{
nexus_init_resources();
- bus_generic_probe(dev);
+ bus_identify_children(dev);
/*
* Explicitly add the legacy0 device here. Other platform
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Wed, Nov 20, 7:53 PM (7 h, 21 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
14746003
Default Alt Text
D47674.diff (26 KB)
Attached To
Mode
D47674: Replace calls to bus_generic_probe with bus_identify_children
Attached
Detach File
Event Timeline
Log In to Comment
diff --git a/sys/dev/dpaa2/dpaa2_rc.c b/sys/dev/dpaa2/dpaa2_rc.c
--- a/sys/dev/dpaa2/dpaa2_rc.c
+++ b/sys/dev/dpaa2/dpaa2_rc.c
@@ -2826,7 +2826,7 @@
dpaa2_rc_add_managed_child(sc, &cmd, &obj);
}
/* Probe and attach MC portals. */
- bus_generic_probe(rcdev);
+ bus_identify_children(rcdev);
rc = bus_generic_attach(rcdev);
if (rc) {
DPAA2_CMD_RC_CLOSE(rcdev, child, &cmd);
@@ -2854,7 +2854,7 @@
dpaa2_rc_add_managed_child(sc, &cmd, &obj);
}
/* Probe and attach managed devices properly. */
- bus_generic_probe(rcdev);
+ bus_identify_children(rcdev);
rc = bus_generic_attach(rcdev);
if (rc) {
DPAA2_CMD_RC_CLOSE(rcdev, child, &cmd);
@@ -2879,7 +2879,7 @@
DPAA2_CMD_RC_CLOSE(rcdev, child, &cmd);
/* Probe and attach the rest of devices. */
- bus_generic_probe(rcdev);
+ bus_identify_children(rcdev);
return (bus_generic_attach(rcdev));
}
@@ -2986,7 +2986,7 @@
* function is supposed to discover such managed objects in the resource
* container and add them as children to perform a proper initialization.
*
* NOTE: It must be called together with bus_generic_probe() and
* bus_generic_attach() before dpaa2_rc_add_child().
*/
static int
@@ -2986,7 +2986,7 @@
* container and add them as children to perform a proper initialization.
*
- * NOTE: It must be called together with bus_generic_probe() and
+ * NOTE: It must be called together with bus_identify_children() and
* bus_generic_attach() before dpaa2_rc_add_child().
*/